@@ -3,6 +3,7 @@
 #
 # This file is part of Invenio.
 # Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2022 Graz University of Technology.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -13,9 +14,6 @@ set -o errexit
 # Quit on unbound symbols
 set -o nounset
 
-pydocstyle invenio_assets tests docs
-isort invenio_assets tests --check-only --diff
-check-manifest --ignore ".*-requirements.txt"
-sphinx-build -qnNW docs docs/_build/html
-python setup.py test
-sphinx-build -qnNW -b doctest docs docs/_build/doctest
+python -m check_manifest
+python -m sphinx.cmd.build -qnNW docs docs/_build/html
+python -m pytest
