@@ -18,26 +18,26 @@ from invenio_assets.cli import collect
 
 def test_collect(app, script_info_assets, testcss):
     """Test assets command in assets CLI."""
-    css_path = join(app.extensions['collect'].static_root, 'test.css')
+    css_path = join(app.extensions["collect"].static_root, "test.css")
 
     # Run collect
     runner = CliRunner()
     assert not exists(css_path)
-    result = runner.invoke(collect, ['-v'], obj=script_info_assets)
+    result = runner.invoke(collect, ["-v"], obj=script_info_assets)
     assert result.exit_code == 0
     assert "Copied: [conftest] '{0}'".format(css_path) in result.output
 
     # Run collect again - no file copied
-    result = runner.invoke(collect, ['-v'], obj=script_info_assets)
+    result = runner.invoke(collect, ["-v"], obj=script_info_assets)
     assert result.exit_code == 0
-    assert 'Copied' not in result.output
+    assert "Copied" not in result.output
 
     # Modify file (and ensure timestamp is different)
     sleep(1)
-    with open(testcss, 'w') as fp:
-        fp.write('* {color: black;}')
+    with open(testcss, "w") as fp:
+        fp.write("* {color: black;}")
 
     # Run collect again - file will be copied
-    result = runner.invoke(collect, ['-v'], obj=script_info_assets)
+    result = runner.invoke(collect, ["-v"], obj=script_info_assets)
     assert result.exit_code == 0
-    assert 'Copied' in result.output
+    assert "Copied" in result.output
